package ltd.llvy.sensitive.annotation;

import cn.hutool.core.util.DesensitizedUtil;
import com.fasterxml.jackson.annotation.JacksonAnnotationsInside;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import ltd.llvy.sensitive.filter.impl.DefaultDesensitizedFilter;
import ltd.llvy.sensitive.support.JsonDesensitizationSerializer;

/**
 * (Desensitization) 脱敏注解
 *
 * @author zweiandlen
 * @since 2024/9/27 14:32
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.FIELD})
@JacksonAnnotationsInside
@JsonSerialize(using = JsonDesensitizationSerializer.class)
public @interface Desensitization {

  /**
   * 脱敏的类型：比如手机号、邮箱.
   *
   * @return 脱敏类型
   */
  DesensitizedUtil.DesensitizedType type() default
      DesensitizedUtil.DesensitizedType.CLEAR_TO_EMPTY;

  /**
   * 过滤的方法：自定义符合条件的脱敏数据.
   *
   * @return 过滤方法
   */
  Class<?> filter() default DefaultDesensitizedFilter.class;
}
